@@ -142,11 +142,7 @@ void OdrsReviewsBackend::reviewsFetched()
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     QScopedPointer<QNetworkReply, QScopedPointerDeleteLater> replyPtr(reply);
     const QByteArray data = reply->readAll();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     const auto networkError = reply->error();
-#else
-    const auto networkError = reply->networkError();
-#endif
     if (networkError != QNetworkReply::NoError) {
         qCWarning(LIBDISCOVER_LOG) << "error fetching reviews:" << reply->errorString() << data;
         m_isFetching = false;
@@ -189,11 +185,7 @@ void OdrsReviewsBackend::submitUsefulness(Review *review, bool useful)
 void OdrsReviewsBackend::usefulnessSubmitted()
 {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     const auto networkError = reply->error();
-#else
-    const auto networkError = reply->networkError();
-#endif
     if (networkError == QNetworkReply::NoError) {
         qCWarning(LIBDISCOVER_LOG) << "Usefulness submitted";
     } else {
@@ -239,19 +231,11 @@ void OdrsReviewsBackend::submitReview(AbstractResource *res, const QString &summ
 
 void OdrsReviewsBackend::reviewSubmitted(QNetworkReply *reply)
 {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     const auto networkError = reply->error();
-#else
-    const auto networkError = reply->networkError();
-#endif
     if (networkError == QNetworkReply::NoError) {
-        qCWarning(LIBDISCOVER_LOG) << "Review submitted";
         AbstractResource *resource = qobject_cast<AbstractResource*>(reply->request().originatingObject());
-        const QJsonArray array = {resource->getMetadata(QStringLiteral("ODRS::review_map")).toObject()};
-        const QJsonDocument document(array);
-        // Remove local file with reviews so we can re-download it next time to get our review
-        QFile file(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/reviews/%1.json").arg(array.first().toObject().value(QStringLiteral("app_id")).toString()));
-        file.remove();
+        qCWarning(LIBDISCOVER_LOG) << "Review submitted" << resource;
+        const QJsonDocument document({resource->getMetadata(QStringLiteral("ODRS::review_map")).toObject()});
         parseReviews(document, resource);
     } else {
         qCWarning(LIBDISCOVER_LOG) << "Failed to submit review: " << reply->errorString();
