@@ -24,6 +24,7 @@
 #include "PackageKitMessages.h"
 #include "utils.h"
 #include "LocalFilePKResource.h"
+#include "libdiscover_backend_debug.h"
 #include <resources/AbstractResource.h>
 #include <QDebug>
 #include <QTimer>
@@ -39,7 +40,7 @@ PKTransaction::PKTransaction(const QVector<AbstractResource*>& apps, Transaction
     Q_ASSERT(!apps.contains(nullptr));
     foreach(auto r, apps) {
         PackageKitResource* res = qobject_cast<PackageKitResource*>(r);
-        m_pkgnames.unite(res->allPackageNames().toSet());
+        m_pkgnames.unite(kToSet(res->allPackageNames()));
     }
 
     QTimer::singleShot(0, this, &PKTransaction::start);
@@ -83,7 +84,7 @@ void PKTransaction::trigger(PackageKit::Transaction::TransactionFlags flags)
                 //FIXME this state shouldn't exist
                 qWarning() << "Installing no packages found!";
                 for(auto app : m_apps) {
-                    qDebug() << "app" << app << app->state() << static_cast<PackageKitResource*>(app)->packages();
+                    qCDebug(LIBDISCOVER_BACKEND_LOG) << "app" << app << app->state() << static_cast<PackageKitResource*>(app)->packages();
                 }
 
                 setStatus(Transaction::DoneWithErrorStatus);
@@ -98,7 +99,7 @@ void PKTransaction::trigger(PackageKit::Transaction::TransactionFlags flags)
     };
     Q_ASSERT(m_trans);
 
-//     connect(m_trans.data(), &PackageKit::Transaction::statusChanged, this, [this]() { qDebug() << "state..." << m_trans->status(); });
+//     connect(m_trans.data(), &PackageKit::Transaction::statusChanged, this, [this]() { qCDebug(LIBDISCOVER_BACKEND_LOG) << "state..." << m_trans->status(); });
     connect(m_trans.data(), &PackageKit::Transaction::package, this, &PKTransaction::packageResolved);
     connect(m_trans.data(), &PackageKit::Transaction::finished, this, &PKTransaction::cleanup);
     connect(m_trans.data(), &PackageKit::Transaction::errorCode, this, &PKTransaction::errorFound);
@@ -177,7 +178,7 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
                 i.remove();
             }
         }
-        removedResources.subtract(kVectorToSet(m_apps));
+        removedResources.subtract(kToSet(m_apps));
 
         if (!packagesToRemove.isEmpty() || !removedResources.isEmpty()) {
             QString msg = QLatin1String("<ul><li>") + PackageKitResource::joinPackages(packagesToRemove, QLatin1String("</li><li>"), {});
