@@ -66,7 +66,9 @@ class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdat
         void resourcesChanged(AbstractResource* res, const QVector<QByteArray>& props);
         void refreshUpdateable();
         void transactionAdded(Transaction* newTransaction);
-        void transactionProgressChanged(int percentage);
+        void transactionProgressChanged();
+        void refreshProgress();
+        QVector<Transaction*> transactions() const;
 
         QSet<AbstractResource*> m_toUpgrade;
         QSet<AbstractResource*> m_upgradeable;
